==> kubernetes-model-coordination-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/coordination/v1/LeaseListBuilder.java <==
package io.fabric8.kubernetes.api.model.coordination.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class LeaseListBuilder extends io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluentImpl<io.fabric8.kubernetes.api.model.coordination.v1.LeaseListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.coordination.v1.LeaseList,io.fabric8.kubernetes.api.model.coordination.v1.LeaseListBuilder>{
  public LeaseListBuilder() {
    this(false);
  }
  public LeaseListBuilder(java.lang.Boolean validationEnabled) {
    this(new LeaseList(), validationEnabled);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent) {
    this(fluent, false);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new LeaseList(), validationEnabled);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent,io.fabric8.kubernetes.api.model.coordination.v1.LeaseList instance) {
    this(fluent, instance, false);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent,io.fabric8.kubernetes.api.model.coordination.v1.LeaseList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseList instance) {
    this(instance,false);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.coordination.v1.LeaseList build() {
    LeaseList buildable = new LeaseList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LeaseListBuilder that = (LeaseListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-coordination-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/coordination/v1/LeaseListBuilder.java <==
package io.fabric8.kubernetes.api.model.coordination.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class LeaseListBuilder extends io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluentImpl<io.fabric8.kubernetes.api.model.coordination.v1.LeaseListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.coordination.v1.LeaseList,io.fabric8.kubernetes.api.model.coordination.v1.LeaseListBuilder>{
  public LeaseListBuilder() {
    this(false);
  }
  public LeaseListBuilder(java.lang.Boolean validationEnabled) {
    this(new LeaseList(), validationEnabled);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent) {
    this(fluent, false);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new LeaseList(), validationEnabled);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent,io.fabric8.kubernetes.api.model.coordination.v1.LeaseList instance) {
    this(fluent, instance, false);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent,io.fabric8.kubernetes.api.model.coordination.v1.LeaseList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseList instance) {
    this(instance,false);
  }
  public LeaseListBuilder(io.fabric8.kubernetes.api.model.coordination.v1.LeaseList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.coordination.v1.LeaseListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.coordination.v1.LeaseList build() {
    LeaseList buildable = new LeaseList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LeaseListBuilder that = (LeaseListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
